Backends
========

.. currentmodule:: queued_storage.backends

.. autoclass:: QueuedStorage
    :members:
    :undoc-members:
    :inherited-members:

.. autoclass:: QueuedFileSystemStorage
    :members:

.. automodule:: queued_storage.backends
    :members:
    :exclude-members: QueuedStorage, QueuedFileSystemStorage
